@@ -48,8 +48,8 @@
 #
 #  - Git
 #    <https://git.sisudoc.org/projects/>
-#    <https://git.sisudoc.org/projects/?p=software/sisu.git;a=summary>
-#    <https://git.sisudoc.org/projects/?p=markup/sisu-markup-samples.git;a=summary>
+#    <https://git.sisudoc.org/projects/sisu>
+#    <https://git.sisudoc.org/projects/sisu-markup>
 module SiSU_CGI_SQL
   class CGI_Common
     def initialize(webserv,opt,image_src,dir)
@@ -59,8 +59,8 @@ module SiSU_CGI_SQL
       <<-'WOK_SQL'
  * Name: SiSU information Structuring Universe
  * Author: Ralph Amissah
-   * http://www.jus.uio.no/sisu
-   * http://www.jus.uio.no/sisu/SiSU/download
+   * https://sisudoc.org/
+   * https://git.sisudoc.org/
       WOK_SQL
     end
     def gpl
@@ -97,7 +97,6 @@ module SiSU_CGI_SQL
    available at these locations:
    <http://www.fsf.org/licenses/gpl.html>
    [http://www.gnu.org/licenses/gpl.html]
-   <http://www.jus.uio.no/sisu/gpl.fsf>
 
  * SiSU uses:
    * Standard SiSU markup syntax,
@@ -105,8 +104,8 @@ module SiSU_CGI_SQL
    * Standard SiSU object citation numbering and system
 
  * Homepages:
-   [http://www.jus.uio.no/sisu]
-   [http://www.sisudoc.org]
+   [https://sisudoc.org]
+   [https://git.sisudoc.org]
 
  * Ralph Amissah
    [ralph@amissah.com]
@@ -145,7 +144,7 @@ module SiSU_CGI_SQL
       <meta name="sourcefile" content="SiSU._sst" />
       SiSU search form (sample): SiSU information Structuring Universe
       </title>
-      <link rel="generator" href="http://www.jus.uio.no/sisu" />
+      <link rel="generator" href="https://git.sisudoc.org" />
       <link rel="shortcut icon" href="#{@image_src}/rb7.ico" />
       <link href="../_sisu/css/html.css" rel="stylesheet">
     </head>
@@ -542,8 +541,8 @@ module SiSU_CGI_SQL
     <br>
       #{v.project} is software for document structuring, publishing and search,
     <br>
-    <a href="http://www.jus.uio.no/sisu" >
-      www.jus.uio.no/sisu
+    <a href="https://sisudoc.org" >
+      sisudoc.org
     </a>
     and
     <a href="http://www.sisudoc.org" >
