@@ -48,8 +48,8 @@
 #
 #  - Git
 #    <https://git.sisudoc.org/projects/>
-#    <https://git.sisudoc.org/projects/?p=software/sisu.git;a=summary>
-#    <https://git.sisudoc.org/projects/?p=markup/sisu-markup-samples.git;a=summary>
+#    <https://git.sisudoc.org/projects/sisu>
+#    <https://git.sisudoc.org/projects/sisu-markup>
 YEAR='2021'
 Sfx={
   txt:                       '.txt',
@@ -220,7 +220,6 @@ Dx={
   lt_xml:                    '&lt;',       gt_xml:                  '&gt;',
 }
 Tex={
-  backslash:                 "\\\\",
   backslash:                 "\\\\",
   tilde:                     '\\\\\\~',
 }
