@@ -48,8 +48,8 @@
 #
 #  - Git
 #    <https://git.sisudoc.org/projects/>
-#    <https://git.sisudoc.org/projects/?p=software/sisu.git;a=summary>
-#    <https://git.sisudoc.org/projects/?p=markup/sisu-markup-samples.git;a=summary>
+#    <https://git.sisudoc.org/projects/sisu>
+#    <https://git.sisudoc.org/projects/sisu-markup>
 module SiSU_Concordance
   require_relative 'se_hub_particulars'                 # se_hub_particulars.rb
     include SiSU_Particulars
@@ -123,7 +123,7 @@ module SiSU_Concordance
         @data=SiSU_HTML::Source::HTML_Environment.new(particulars).tuned_file_instructions
         @file=SiSU_Env::FileOp.new(@md)
         @fnb=@md.fnb
-        @lex_button=%{<a href="http://www.jus.uio.no/sisu/" target="_top"><img border="0" height="44" width="144" valign="center" src="#{@file.path_rel_links.html_seg_2}_sisu/image/sisu.png" alt="SiSU home --&gt;"></a>}
+        @lex_button=%{<a href="https://git.sisudoc.org/" target="_top"><img border="0" height="44" width="144" valign="center" src="#{@file.path_rel_links.html_seg_2}_sisu/image/sisu.png" alt="SiSU home --&gt;"></a>}
         @doc_details =<<WOK
 <table summary="links to text related to this rudimentary index" width="96%" border="0" cellpadding="0" align="center"><tr><td width="2%" align="right">&nbsp;</td><td width="94%" valign="top" align="justify"><h1 class="small"><a href="#{@md.file.base_filename.html_segtoc}"><b>#{@md.title.full}</b></a></h1><p class="bold">#{@md.author}</p></td></tr></table>
 WOK
@@ -156,7 +156,7 @@ WOK
   <meta name="Description" content="&nbsp;SiSU created">
   <meta name="keywords" content="word index for #{@md.title.full}">
   <meta name="generator" content="SiSU (Linux &amp; Ruby!)">
-  <link rel="generator" href="http://www.jus.uio.no/sisu" />
+  <link rel="generator" href="https://git.sisudoc.org/" />
   <link rel="shortcut icon" href="../_sisu/image/rb7.ico" />
   #{stylesheet.css_head_seg}
 </head>
