@@ -48,8 +48,8 @@
 #
 #  - Git
 #    <https://git.sisudoc.org/projects/>
-#    <https://git.sisudoc.org/projects/?p=software/sisu.git;a=summary>
-#    <https://git.sisudoc.org/projects/?p=markup/sisu-markup-samples.git;a=summary>
+#    <https://git.sisudoc.org/projects/sisu>
+#    <https://git.sisudoc.org/projects/sisu-markup>
 module SiSU_HarvestTopics
   require_relative 'html_harvest_author_format'          # html_harvest_author_format.rb
   require_relative 'html_parts'                          # html_parts.rb
@@ -685,7 +685,7 @@ module SiSU_HarvestTopics
 <meta name="dc.title" content= "SiSU metadata harvest, Topics - SiSU information Structuring Universe, Structured information Serialised Units" />
 <meta name="dc.subject" content= "document structuring, ebook, publishing, PDF, LaTeX, XML, ODF, SQL, postgresql, sqlite, electronic book, electronic publishing, electronic document, electronic citation, data structure, citation systems, granular search, digital library" />
 <meta name="generator" content="#{sv.project} #{sv.version} of #{sv.date_stamp} (n*x and Ruby!)" />
-<link rel="generator" href="http://www.jus.uio.no/sisu/SiSU" />
+<link rel="generator" href="https://git.sisudoc.org/sisu" />
 <link href="#{css_path}" rel="stylesheet">
 <link rel="shortcut icon" href="../_sisu/image/rb7.ico" />
 </head>
