@@ -48,8 +48,8 @@
 #
 #  - Git
 #    <https://git.sisudoc.org/projects/>
-#    <https://git.sisudoc.org/projects/?p=software/sisu.git;a=summary>
-#    <https://git.sisudoc.org/projects/?p=markup/sisu-markup-samples.git;a=summary>
+#    <https://git.sisudoc.org/projects/sisu>
+#    <https://git.sisudoc.org/projects/sisu-markup>
 module SiSU_Manifest
   require_relative 'se'                                 # se.rb
     include SiSU_Env
@@ -896,7 +896,7 @@ SiSU manifest: #{@md.title.full}
 </title>
 <meta http-equiv="Content-Type" content="text/html;charset=utf-8" />
 <meta name="sourcefile" content="#{@md.fns}" />
-<link rel="generator" href="http://www.jus.uio.no/sisu" />
+<link rel="generator" href="https://git.sisudoc.org/" />
 <link rel="shortcut icon" href="#{@f.path_rel_links.html_scroll_css}_sisu/image_sys/rb7.ico" />
 #{@stylesheet.css_head}
 </head>
