@@ -48,8 +48,8 @@
 #
 #  - Git
 #    <https://git.sisudoc.org/projects/>
-#    <https://git.sisudoc.org/projects/?p=software/sisu.git;a=summary>
-#    <https://git.sisudoc.org/projects/?p=markup/sisu-markup-samples.git;a=summary>
+#    <https://git.sisudoc.org/projects/sisu>
+#    <https://git.sisudoc.org/projects/sisu-markup>
 module SiSU_JSONutils
   require_relative 'generic_parts'                      # generic_parts.rb
   class Clean
@@ -634,7 +634,7 @@ module SiSU_XML_Tags #Format
      * #{rubyv}
      * #{sc}
      * #{lastdone}
-     * SiSU http://www.jus.uio.no/sisu
+     * SiSU https://git.sisudoc.org/
 -->
 WOK
      else
@@ -645,7 +645,7 @@ WOK
      * #{rubyv}
      * #{sc}
      * #{lastdone}
-     * SiSU http://www.jus.uio.no/sisu
+     * SiSU https://git.sisudoc.org/
 -->
 WOK
       end
