@@ -48,8 +48,8 @@
 #
 #  - Git
 #    <https://git.sisudoc.org/projects/>
-#    <https://git.sisudoc.org/projects/?p=software/sisu.git;a=summary>
-#    <https://git.sisudoc.org/projects/?p=markup/sisu-markup-samples.git;a=summary>
+#    <https://git.sisudoc.org/projects/sisu>
+#    <https://git.sisudoc.org/projects/sisu-markup>
 module SiSU_Relaxng
   require_relative 'se'                                 # se.rb
   class RelaxNG
@@ -89,7 +89,6 @@ module SiSU_Relaxng
    available at these locations:
    <http://www.fsf.org/licenses/gpl.html>
    [http://www.gnu.org/licenses/gpl.html]
-   <http://www.jus.uio.no/sisu/gpl.fsf>
 
  * SiSU uses:
    * Standard SiSU markup syntax,
@@ -97,8 +96,8 @@ module SiSU_Relaxng
    * Standard SiSU object citation numbering and system
 
  * Homepages:
-   [http://www.jus.uio.no/sisu]
-   [http://www.sisudoc.org]
+   [https://www.sisudoc.org]
+   [https://git.sisudoc.org]
 
  * Ralph Amissah
    [ralph@amissah.com]
