@@ -48,8 +48,8 @@
 #
 #  - Git
 #    <https://git.sisudoc.org/projects/>
-#    <https://git.sisudoc.org/projects/?p=software/sisu.git;a=summary>
-#    <https://git.sisudoc.org/projects/?p=markup/sisu-markup-samples.git;a=summary>
+#    <https://git.sisudoc.org/projects/sisu>
+#    <https://git.sisudoc.org/projects/sisu-markup>
 module SiSU_XML_Format
   require_relative 'dp'                                 # dp.rb
   require_relative 'xml_parts'                          # xml_parts.rb
@@ -83,7 +83,7 @@ module SiSU_XML_Format
       @full_title=@subtitle=@author=@subject=@description=@publisher=@contributor=@date=@type=@format=@identifier=@source=@language=@relation=@coverage=@rights=@copyright=@owner=@keywords=''
       @md=@@md
       # DublinCore 1 - title
-      @rdfurl=%{  rdf:about="http://www.jus.uio.no/lm/toc"\n}
+      @rdfurl=%{  rdf:about="https://sisudoc.org"\n}
       if defined? @md.title.full \
       and @md.title.full                          # DublinCore 1 - title
         @rdf_title=%{    dc.title="#{seg_name}#{@md.title.full}"\n}
