@@ -48,8 +48,8 @@
 #
 #  - Git
 #    <https://git.sisudoc.org/projects/>
-#    <https://git.sisudoc.org/projects/?p=software/sisu.git;a=summary>
-#    <https://git.sisudoc.org/projects/?p=markup/sisu-markup-samples.git;a=summary>
+#    <https://git.sisudoc.org/projects/sisu>
+#    <https://git.sisudoc.org/projects/sisu-markup>
 module SiSU_XML_Munge
   require_relative 'xml_parts'                          # xml_parts.rb
   class Trans
@@ -468,7 +468,7 @@ module SiSU_XML_Tags #Format
     def initialize(md='',seg_name=[],tracker=0)
       @full_title=@subtitle=@author=@subject=@description=@publisher=@contributor=@date=@date_created=@date_issued=@date_available=@date_valid=@date_modified=@type=@format=@identifier=@source=@language=@relation=@coverage=@rights=@copyright=@owner=@keywords=''
       @md=md
-      @rdfurl=%{  rdf:about="http://www.jus.uio.no/lm/toc"\n}
+      @rdfurl=%{  rdf:about="https://sisudoc.org/spine/topics.html"\n}
       if defined? @md.title.full \
       and @md.title.full                          # DublinCore 1 - title
         @rdf_title=%{    dc.title="#{seg_name}#{@md.title.full}"\n}
@@ -614,7 +614,7 @@ module SiSU_XML_Tags #Format
      * #{rubyv}
      * #{sc}
      * #{lastdone}
-     * SiSU http://www.jus.uio.no/sisu
+     * SiSU https://sisudoc.org
 -->
 WOK
      else
@@ -625,7 +625,7 @@ WOK
      * #{rubyv}
      * #{sc}
      * #{lastdone}
-     * SiSU http://www.jus.uio.no/sisu
+     * SiSU https://sisudoc.org
 -->
 WOK
       end
