@@ -11,7 +11,7 @@ module Project_details
     'documents - structuring, publishing in multiple formats & search'
   end
   def self.homepage
-    'http://www.sisudoc.org'
+    'https://www.sisudoc.org'
   end
   def self.thor
     "ruby-thor files for the installation/setup of #{name}"
@@ -390,7 +390,7 @@ proceed? }
       vn=version_number(vi)
       <<-WOK
 - sisu_#{vn}.orig.tar.xz (#{vi[:date]}:#{vi[:date_stamp].gsub(/20\d\dw/,'')})
-  http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=log;h=refs/tags/sisu_#{vn}
+  https://git.sisudoc.org/projects/sisu/tag/?h=sisu_#{vn}
       WOK
     end
     def self.changelog_header_release(filename,ch,vi)
@@ -438,7 +438,7 @@ proceed? }
       vn=version_number(vi)
       <<-WOK
 - sisu_#{vn}.orig.tar.xz (Open commit window: #{vi[:date]}; Pre-Release)
-  http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=log;h=refs/tags/sisu_#{vn}
+  https://git.sisudoc.org/projects/sisu/tag/?h=sisu_#{vn}
       WOK
     end
     def self.changelog_header_pre_release_write(filename,ch)
@@ -577,7 +577,6 @@ Gem::Specification.new do |s|
                      Dir['bin/#{Project_details.name.downcase}gem'] +
                      Dir['bin/#{Project_details.name.downcase}']
   s.executables << '#{Project_details.name.downcase}gem' << '#{Project_details.name.downcase}'
-  s.has_rdoc       = false
 end
     WOK
   end
@@ -599,7 +598,6 @@ Gem::Specification.new do |s|
                      Dir['bin/#{Project_details.name.downcase}gem'] +
                      Dir['bin/#{Project_details.name.downcase}']
   s.executables << '#{Project_details.name.downcase}gem' << '#{Project_details.name.downcase}'
-  s.has_rdoc       = false
 end
     WOK
   end
